@@ -256,7 +256,11 @@ def run_command_helper(config: Config, command: str):
 
         if "ERROR: We require files to be sorted by readname, will exit" in line:
             logger.debug(line)
-            s = f"The alignment file ({config['bam']}) has to be sorted by filename. "
+            s = (
+                f"\n\nThe alignment file has to be sorted by filename. "
+                + f"\nUse samtools sort -n to sort the file: "
+                + f"'samtools sort -n {config['bam']}' \n"
+            )
             raise metadamageError(s)
 
         # continue running and logging
@@ -293,6 +297,11 @@ def run_LCA(config: Config, force: bool = False) -> None:
                 f"{config['sample']}: The alignment file is invalid."
             )
 
+        if not metaDMG_cpp_is_valid(config):
+            raise metadamageError()
+
+        config["metaDMG_cpp"]
+
         logger.info(f"LCA has to be computed. This can take a while, please wait.")
 
         command_LCA = get_LCA_command(config)
@@ -332,6 +341,9 @@ def run_damage_no_lca(config: Config, force: bool = False) -> None:
                 f"{config['sample']}: The alignment file is invalid."
             )
 
+        if not metaDMG_cpp_is_valid(config):
+            raise metadamageError()
+
         logger.info(f"Computing damage. NOTE: NO LCA.")
 
         command_damage = get_damage_command(config)
@@ -491,6 +503,19 @@ def BAM_file_is_valid(config: Config) -> bool:
     return True
 
 
+def metaDMG_cpp_is_valid(config: Config) -> bool:
+
+    if not Path(config["metaDMG_cpp"]).is_file():
+        logger.error(f"The metaDMG-cpp binary does not exist: {config['metaDMG_cpp']}.")
+        return False
+
+    if config["bam"].stat().st_size == 0:
+        logger.error(f"The metaDMG-cpp binary is of size 0: {config['metaDMG_cpp']}.")
+        return False
+
+    return True
+
+
 #%%
 
 
